@@ -94,7 +94,7 @@ void FiltersView::enableModel()
     QString title = QString("_%1_").arg(headerItem->text());
     QFont font;
     QFontMetrics fm(font);
-#if QT_VERSION_GTE(5, 11)
+#if QT_VERSION_GTE(5, 11, 0)
     int w = fm.horizontalAdvance(title);
 #else
     int w = fm.width(title);
@@ -467,6 +467,9 @@ void FiltersView::onItemChanged(QStandardItem * item)
     parentFolder = _model.invisibleRootItem();
   }
   QStandardItem * leftItem = parentFolder->child(row);
+  if (!leftItem) {
+    return;
+  }
   auto folder = dynamic_cast<FilterTreeFolder *>(leftItem);
   if (folder) {
     folder->applyVisibilityStatusToFolderContents();
@@ -608,6 +611,9 @@ QStandardItem * FiltersView::getFolderFromPath(QStandardItem * parent, QList<QSt
 
 void FiltersView::saveFiltersVisibility(QStandardItem * item)
 {
+  if (!item) {
+    return;
+  }
   auto filterItem = dynamic_cast<FilterTreeItem *>(item);
   if (filterItem) {
     FiltersVisibilityMap::setVisibility(filterItem->hash(), filterItem->isVisible());
