@@ -206,7 +206,7 @@ void FilterThread::run()
   _failed = false;
   QString fullCommandLine;
   try {
-    fullCommandLine = QString::fromLocal8Bit(GmicQt::commandFromOutputMessageMode(_messageMode));
+    fullCommandLine = QString::fromLatin1(GmicQt::commandFromOutputMessageMode(_messageMode));
     GmicQt::appendWithSpace(fullCommandLine, _command);
     GmicQt::appendWithSpace(fullCommandLine, _arguments);
     _gmicAbort = false;
