@@ -214,7 +214,7 @@ void PreviewWidget::updateErrorImage()
   gmic_image<float> image;
   getOriginalImageCrop(image);
   image.move_to(images);
-  QString fullCommandLine = QString::fromLocal8Bit(GmicQt::commandFromOutputMessageMode(DialogSettings::outputMessageMode()));
+  QString fullCommandLine = QString::fromLatin1(GmicQt::commandFromOutputMessageMode(DialogSettings::outputMessageMode()));
   fullCommandLine += QString(" _host=%1 _tk=qt").arg(GmicQt::HostApplicationShortname);
   fullCommandLine += QString(" _preview_width=%1").arg(width());
   fullCommandLine += QString(" _preview_height=%1").arg(height());
@@ -492,7 +492,7 @@ void PreviewWidget::wheelEvent(QWheelEvent * event)
 {
   double degrees = event->angleDelta().y() / 8.0;
   int steps = static_cast<int>(std::fabs(degrees) / 15.0);
-#if QT_VERSION_GTE(5, 14)
+#if QT_VERSION_GTE(5, 14, 0)
   const QPoint position = event->position().toPoint();
 #else
   const QPoint position = event->pos();
