@@ -26,6 +26,7 @@
 #define GMIC_QT_SEARCHFIELDWIDGET_H
 #include <QIcon>
 #include <QWidget>
+#include "Common.h"
 
 namespace Ui
 {
@@ -40,7 +41,7 @@ class SearchFieldWidget : public QWidget {
   Q_OBJECT
 public:
   explicit SearchFieldWidget(QWidget * parent = nullptr);
-  ~SearchFieldWidget();
+  ~SearchFieldWidget() override;
   QString text() const;
 public slots:
   void clear();
@@ -55,7 +56,7 @@ private:
   QIcon _clearIcon;
   QIcon _findIcon;
   QLineEdit * _lineEdit;
-#if QT_VERSION >= 0x050200
+#if QT_VERSION_GTE(5, 2, 0)
   QAction * _action;
 #else
   QToolButton * _button;
